
#ifndef _C14_fi658_
#define _C14_fi658_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F586_3155(EIF_REFERENCE);
extern void EIF_Minit658(void);
extern EIF_INTEGER_32 F688_3633(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
